@@ -109,7 +109,9 @@ class TestConfigurator(unittest.TestCase):
         self.assertEqual(c.get("MySqlTable", "path"), "/tmp/foo/bar/my_db1/tbl1/")
 
         self.assertEqual(c.get("MySqlTable", "format"), "delta")
-        self.assertEqual(c.get("MySqlTable", "options"), dict(key1="val1", key2="val2"))
+        self.assertEqual(
+            c.get("MySqlTable", "options"), {"key1": "val1", "key2": "val2"}
+        )
         self.assertEqual(c.get("MySqlTable", "partitioned_by"), ["a", "b"])
         self.assertEqual(
             c.get("MySqlTable", "clustered_by"),
@@ -124,7 +126,8 @@ class TestConfigurator(unittest.TestCase):
         )
         self.assertEqual(c.get("MySqlTable", "comment"), "Dummy Database 1 table 1")
         self.assertEqual(
-            c.get("MySqlTable", "tblproperties"), dict(key1="val1", key2="val2")
+            c.get("MySqlTable", "tblproperties"),
+            {"key1": "val1", "key2": "val2", "my.key.3": "true"},
         )
         self.assertEqual(
             SchemaManager().get_schema("MySqlTable"),
@@ -135,9 +138,12 @@ class TestConfigurator(unittest.TestCase):
             SchemaManager().get_schema_as_string("MyDetailsTable"),
             """a int, b int, c string, d timestamp, another int""",
         )
+
         c.set_prod()
+        statements = list(SqlExecutor(sql).get_statements("*"))
+        self.assertEqual(len(statements), 3)
         self.assertEqual(
-            list(SqlExecutor(sql).get_statements("*"))[1],
+            statements[1],
             dedent(
                 """\
 
